@@ -2,7 +2,7 @@
 // timer.cpp
 // ~~~~~~~~~
 //
-// Copyright (c) 2003-2014 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2015 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -25,14 +25,14 @@ public:
 
   ~printer()
   {
-    std::cout << "Final count is " << count_ << "\n";
+    std::cout << "Final count is " << count_ << std::endl;
   }
 
   void print()
   {
     if (count_ < 5)
     {
-      std::cout << count_ << "\n";
+      std::cout << count_ << std::endl;
       ++count_;
 
       timer_.expires_at(timer_.expires_at() + boost::posix_time::seconds(1));
